Package: ggscribe
Title: Publication-Quality 'ggplot2' Annotation
Version: 0.1.1
Authors@R: 
    person(given = "David", family = "Hodge", 
           email = "davidhodge931@gmail.com", 
           role = c("aut", "cre", "cph"), 
           comment = c(ORCID = "0000-0002-3868-7501"))
Description: Annotation helper functions for publication-quality 'ggplot2' 
    visualisation. These functions make it easier to annotate plots in 
    a way that stays consistent with the set theme.
License: MIT + file LICENSE
URL: https://github.com/davidhodge931/ggscribe,
        https://davidhodge931.github.io/ggscribe/
BugReports: https://github.com/davidhodge931/ggscribe/issues
Depends: R (>= 4.1.0)
Imports: farver, ggplot2 (>= 4.0.0), glue, grid, rlang, scales
Encoding: UTF-8
Language: en-GB
RoxygenNote: 7.3.3
Suggests: blends, dplyr, flexoki, ggrefine, ggwidth, jumble, knitr,
        rmarkdown, spelling, stringr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-04 03:01:52 UTC; david
Author: David Hodge [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-3868-7501>)
Maintainer: David Hodge <davidhodge931@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-04 12:50:15 UTC
Built: R 4.5.2; ; 2026-05-04 22:50:11 UTC; unix
