% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme-sec-axis-text.R
\name{theme_sec_axis_text}
\alias{theme_sec_axis_text}
\title{Theme adjustments optimised for secondary axis text annotations}
\usage{
theme_sec_axis_text(
  axis = NULL,
  axis_ticks_to = "transparent",
  axis_line_to = "transparent",
  axis_text_to = "keep",
  axis_title_to = "keep"
)
}
\arguments{
\item{axis}{Character. "x", "y", or NULL (defaults to both).}

\item{axis_ticks_to}{Action for ticks: "transparent", "blank", or "keep".}

\item{axis_line_to}{Action for lines: "transparent", "blank", or "keep".}

\item{axis_text_to}{Action for text: "transparent", "blank", or "keep".}

\item{axis_title_to}{Action for titles: "transparent", "blank", or "keep".}
}
\value{
A ggplot2 theme object.
}
\description{
Theme adjustments optimised for secondary axis text annotations
}
\seealso{
\code{\link[=sec_axis_text]{sec_axis_text()}}, \code{\link[=guide_sec_axis_text]{guide_sec_axis_text()}}

\code{\link[=axis_ticks]{axis_ticks()}}, \code{\link[=axis_line]{axis_line()}},
\code{\link[=axis_text]{axis_text()}}, \code{\link[=reference_line]{reference_line()}}
}
