% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ggscribe-package.R
\docType{package}
\name{ggscribe-package}
\alias{ggscribe}
\alias{ggscribe-package}
\title{ggscribe: Publication-Quality 'ggplot2' Annotation}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

Annotation helper functions for publication-quality 'ggplot2' visualisation. These functions make it easier to annotate plots in a way that stays consistent with the set theme.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/davidhodge931/ggscribe}
  \item \url{https://davidhodge931.github.io/ggscribe/}
  \item Report bugs at \url{https://github.com/davidhodge931/ggscribe/issues}
}

}
\author{
\strong{Maintainer}: David Hodge \email{davidhodge931@gmail.com} (\href{https://orcid.org/0000-0002-3868-7501}{ORCID}) [copyright holder]

}
\keyword{internal}
