% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reference-line.R
\name{reference_line}
\alias{reference_line}
\title{Annotate a reference line}
\usage{
reference_line(
  ...,
  xintercept = NULL,
  yintercept = NULL,
  colour = NULL,
  linewidth = NULL,
  linetype = "dashed"
)
}
\arguments{
\item{...}{Not used. Forces named arguments.}

\item{xintercept}{Draw a vertical reference line at this x position.}

\item{yintercept}{Draw a horizontal reference line at this y position.}

\item{colour}{Inherits from \code{axis.line} in the set theme.}

\item{linewidth}{Inherits from \code{axis.line} in the set theme. Supports \code{rel()}.}

\item{linetype}{Defaults to \code{"dashed"}.}
}
\value{
A list of ggplot2 annotation layers.
}
\description{
Draws a reference line within the panel, with style defaults taken from the
\code{axis.line} element of the set theme.
}
\examples{
library(ggplot2)
library(dplyr)

set_theme(
  ggrefine::theme_grey(
    panel_heights = rep(unit(50, "mm"), 100),
    panel_widths = rep(unit(75, "mm"), 100),
  )
)

mtcars |>
  ggplot(aes(x = wt, y = mpg, colour = as.factor(gear), fill = as.factor(gear))) +
  scale_colour_discrete(palette = blends::multiply(get_theme()$palette.colour.discrete)) +
  #clip = "off" is required for axis_text, axis_ticks and axis_bracket
  coord_cartesian(clip = "off") +
  #reference lines and shade
  ggscribe::reference_line(xintercept = 2.4) +
  ggscribe::reference_line(yintercept = 12)  +
  ggscribe::panel_shade(
    xmin = 4,
    xmax = 5,
  ) +
  #top axis
  scale_x_continuous(
    sec.axis = ggscribe::sec_axis_text(
      breaks = c(mean(c(4, 5))),
      labels = c("Range"),
      guide = ggscribe::guide_sec_axis_text(
        angle = 90,
      )
    )
  ) +
  ggscribe::axis_bracket(
    position = "top",
    breaks = c(4, 5),
  ) +
  ggscribe::axis_text(
    position = "top",
    breaks = c(2.4),
    labels = c("Threshold"),
  ) +
  #right axis
  ggscribe::axis_text(
    position = "right",
    breaks = 12,
    labels = "Threshold",
  ) +
  #'geom
  geom_point() +
  #annotations fit plot
  theme(plot.background = element_rect(colour = "grey92"))

}
\seealso{
\code{\link[=axis_line]{axis_line()}}, \code{\link[=axis_ticks]{axis_ticks()}},
\code{\link[=axis_text]{axis_text()}}, \code{\link[=axis_bracket]{axis_bracket()}}, \code{\link[=panel_shade]{panel_shade()}},
\code{\link[=sec_axis_text]{sec_axis_text()}}
}
